require(oppla)
require(parallel)

costfunLHS <- function(obs, model_file, control, costfun = cost, ...) {
  cf <- control$costfun[[1]]
  model <- oppla::oppla_read(file = model_file, forcing = FALSE)
  error <- costfun(obs = obs, model = model, cut_date = cf$cut_date, max_depth = cf$max_depth,
                   coco = control$coco[[1]], ...)
  return(error)
}

costLHS <- function(files, getObs, LHSfun = costfunLHS, costfun, norm = "se",
                    cost_terms = list(total_all_zoo = c("DIN", "DIP", "Chl", "zoo_I"),
                                      total_SVM = c("DIN", "DIP", "Chl", "zoo_SVM_I"),
                                      total_noSVM = c("DIN", "DIP", "Chl", "zoo_noSVM_I"),
                                      total_SVM_noSVM = c("DIN", "DIP", "Chl", "zoo_SVM_I", "zoo_noSVM_I")), ...) {
  i1 <- oppla::onc_info(filename = files[1], close = TRUE)
  control <- oppla::nml_read(file.path(dirname(files[1]), i1$att$control_file))
  obs <- getObs(oppla_inp = file.path(dirname(files[1]), i1$att$control_file), ...)
  cl <- parallel::makeCluster(parallel::detectCores() - 3)
  costvalues <- parallel::clusterApply(cl = cl, x = files,
                                       fun = function(x, obs, control, LHSfun, costfun, norm, cost_terms) {
                                         nf <- strcapture(pattern = "_([0-9]+)\\.nc", x = x,
                                                          proto = data.frame(N = integer()))
                                         cost <- LHSfun(obs = obs, model_file = x, control = control, costfun = costfun,
                                                        norm = norm)
                                         return(c(cost, sapply(X = cost_terms, FUN = function(x) sum(cost[x])), N = nf$N))
                                       }, obs = obs, control = control, LHSfun = LHSfun, costfun = costfun,
                                       norm = norm, cost_terms = cost_terms)
  parallel::stopCluster(cl)
  allJ <- as.data.frame(do.call(what = rbind, args = costvalues))
  return(allJ[order(allJ$N), setdiff(names(allJ), "N")])
}

costLHSiqd <- function(files, obs, LHSfun = costfunLHS, costfun,
                       cost_terms = list(total_all_zoo = c("DIN", "DIP", "Chl", "zoo_TC"),
                                         total_SVM = c("DIN", "DIP", "Chl", "zoo_C"),
                                         total_noSVM = c("DIN", "DIP", "Chl", "zoo_noSVM_C"),
                                         total_SVM_noSVM = c("DIN", "DIP", "Chl", "zoo_C", "zoo_noSVM_C"))) {
  i1 <- oppla::onc_info(filename = files[1], close = TRUE)
  control <- oppla::nml_read(file.path(dirname(files[1]), i1$att$control_file))
  cl <- parallel::makeCluster(parallel::detectCores() - 2)
  costvalues <- parallel::clusterApply(cl = cl, x = files,
                                       fun = function(x, obs, control, LHSfun, costfun, cost_terms) {
                                         nf <- strcapture(pattern = "_([0-9]+)\\.nc", x = x,
                                                          proto = data.frame(N = integer()))
                                         cost <- LHSfun(obs = obs, model_file = x, control = control, costfun = costfun)
                                         return(c(cost, sapply(X = cost_terms, FUN = function(x) sum(cost[x])), N = nf$N))
                                       }, obs = obs, control = control, LHSfun = LHSfun, costfun = costfun,
                                       cost_terms = cost_terms)
  parallel::stopCluster(cl)
  allJ <- as.data.frame(do.call(what = rbind, args = costvalues))
  return(allJ[order(allJ$N), setdiff(names(allJ), "N")])
}
