#!/bin/bash
# costfun.sh npopsiz nml_gafort cost_file generation param nml_in oppla_inp gafort_path oppla_path costfun cost
# npopsiz     population size
# nml_gafort  gafort namelist file (gafort.in)
# cost_file   file name for cost-function values (oppla_cost.csv)
# generation  current generation number
# param       namelist file name for all parameter sets for this generation
# nml_in      default (template) parameter namelist file
# oppla_inp   oppla control file
# gafort_path path to the gafort executable including the final slash
# oppla_path  path to the oppla executable including the final slash
# costfun     path to the costfun R script
# cost        name of the actual cost function
. ~/.bash_profile
nml=oppla_svm_GA$4.nml
model=LS_svm_GA$4.nc
oppla_inp=${7:-oppla.inp}
costfun=${10:-costfun.R}
R --no-save --slave <<-EOF
  source("${8}make_inp.R")
  make_inp(nml_gafort = "$2", nml_param = "$5", nml_control = "${oppla_inp}", nml_in = "$6", nml_out = "${nml}")
  warnings()
EOF
folders=(fitness{1..20})
for folder in ${folders[@]:0:$1}; do
    ${9}oppla ${oppla_inp} -o ${folder}/${model} -f \
	-p ${folder}/${nml} &> ${folder}/log_$4 & # start simulation
done
wait                                    # wait until all simulations have finished
R --no-save --slave <<-EOF
  source("${10}")
  obs <- readRDS("obs.rds")
  costfunGA(pop_size = $1, cost_file = "$3", model_file = "${model}", obs = obs, cost = ${11})
  warnings()
EOF
