function k = K(tmp, sal, prs)
%EOS80.K: bulk modulus needed for sigma_p (Millero et al. 1980)
% K = EOS80.K(TMP, SAL, PRS)
%   TMP     temperature at pressure pres in °C
%   SAL     salinity in psu
%   PRS     pressure in bar
  a = 54.6746e0 + tmp.*(-0.603459e0 + tmp.*(1.09987e-2 - tmp.*6.1670e-5));
  b = 7.944e-2 + tmp.*(1.6483e-2 - tmp.*5.3009e-4);
  c = 2.2838e-3 - tmp.*(1.0981e-5 + tmp.*1.6078e-6);
  d = 1.91075e-4;
  e = -9.9348e-7 + tmp.*(2.0816e-8 + tmp.*9.1697e-10);
  Aw = 3.239908e0 + tmp.*(1.43713e-3 + tmp.*(1.16092e-4 - tmp.*5.77905e-7));
  Bw = 8.50935e-5 + tmp.*(-6.12293e-6 + tmp.*5.2787e-8);
  K0w = 19652.21e0 + tmp.*(148.4206e0 + tmp.*(-2.327105e0 + tmp.*(1.360477e-2 - tmp.*5.155288e-5)));
  A0 = Aw + sal.*(c + sqrt(sal).*d);
  B0 = Bw + e.*sal;
  K0 = K0w + sal.*(a + sqrt(sal).*b);
  k = K0 + prs.*(A0 + prs.*B0);
end
