function [values, names] = get(nls, names)
%NML.GET get numeric namelist values
% VALUES          = NML.GET(NLS, NAMES)
% [VALUES, NAMES] = NML.GET(NLS)
%  NLS        namelist structure obtained with nml.read
%  NAMES      cell array of strings describing the namelist(s) and parameter(s)
%             parameter value(s) must be numeric
%             example: {'parphy(2).alpha'}
% with one input argument, extract all numeric parameters
% returns
%  VALUES     vector of values corresponding to names
  if nargin == 1
    np = 0;
    for nl=fieldnames(rmfield(nls, 'units'))'
      nlnam = nl{1};
      for nnl=1:length(nls.(nlnam))
        for pn=fieldnames(nls.(nlnam)(nnl))'
          pnam = pn{1};
          if isnumeric(nls.(nlnam)(nnl).(pnam))
            for nv=1:length(nls.(nlnam)(nnl).(pnam))
              np = np + 1;
              names{np} = sprintf('%s(%d).%s(%d)', nlnam, nnl, pnam, nv);
            end
          end
        end
      end
    end
  end
  for nv=length(names):-1:1
    pnl = nml.path(names{nv});
    values(nv) = nls.(pnl.name)(pnl.index).(pnl.param)(pnl.parind);
  end
end
