function nlv = read (file, nlv)
%NML.READ read FORTRAN namelist(s) into MATLAB structure
% NV = NML.READ(FILE, NM)
%  FILE file name
%  NM   existing structure to which to add the namelists as additional fields
%  NV   structure (based on NM) with fields corresponding to namelists
  c = regexprep(fileread(file), '![^\n]*', '');      % read file and remove comments
  ncs = regexp(c, '&\w+.+?(?=/\s+(&|$))', 'match');  % cell array with namelists
  if nargin == 1, nlv = struct; end
  for nnml=1:length(ncs)
    pnl = regexp(ncs{nnml}, '&(?<name>\w+)', 'names');
    if isfield(nlv, pnl.name)
      inml = length(nlv.(pnl.name)) + 1;
    else
      inml = 1;
      nlv.(pnl.name) = struct;
    end
    var = regexp(ncs{nnml}, '(?<name>[^\s,=]+?)\s*=\s*(?<content>[^=]+)(?=[\s,][^\s,=]+\s*=|$)', 'names');
    for n=1:length(var)
      vv = regexp(deblank(var(n).content), '(?<tag>''\w+'')?[, ]*(?<value>[-+./\w]+)[, ]*(?<units>''[^'']+'')?', 'names');
      if isempty(vv)
        vv(1).value = '';
      end
      nv = str2double(vv(1).value);
      if isnan(nv)   % strings
        nlv.(pnl.name)(inml).(var(n).name) = {vv.value};
      else                                % numbers (with units)
        nlv.(pnl.name)(inml).(var(n).name) = str2double({vv.value});
        u = {vv.units};
        t = {vv.tag};
        u(cellfun(@isempty, u)) = u(end); % use last units for all empty
        t(cellfun(@isempty, t)) = t(1);   % use first tag for all empty
        nlv.units.(pnl.name)(inml).(var(n).name) = u;
        nlv.tag.(pnl.name)(inml).(var(n).name) = t;
      end
    end
  end
end
