function nls = set(nls, names, values)
%NML.SET set namelist values
% NLS = NML.SET(NLS, NAMES, VALUES)
%  NLS        namelist structure obtained with nml.read
%  NAMES      cell array of (cell arrays of) strings describing the namelist
%             and parameters, e.g., 'cmo.alpha', 'cfo(2).phi(3)', 'cfo(1).phi(0)',
%             '{cmo.alpha}' or '{cfo(1).Imax cfo(2).Imax}'
%  VALUES     vector of values corresponding to names
%             parameter indices of 0 indicate that the corresponding VALUES
%             are factors to be multiplied with the whole parameter vector
%             this also applies to (groups of) names enclosed in curly braces
% returns
%  NLS        modified namelist structure
  for nv=1:length(names)
    name = names{nv};
    if iscell(name)
      nls = nml.set(nls, name, values(nv).*nml.get(nls, name));
    else
      pnl = nml.path(name);
      if pnl.parind == 0
        nls.(pnl.name)(pnl.index).(pnl.param) ...
            = nls.(pnl.name)(pnl.index).(pnl.param).*values(nv);
      else
        nls.(pnl.name)(pnl.index).(pnl.param)(pnl.parind) = values(nv);
      end
    end
  end
end
