function write (file, snml)
%NML.WRITE write FORTRAN namelist(s) from MATLAB structure
% NML.WRITE(FILE, NML)
%  FILE file name
%  SNML structure with fields corresponding to namelists
  if ~isfield(snml, 'units')
    snml.units = struct;                  % dummy units structure
  end
  if ~isfield(snml, 'tag')
    snml.tag = struct;                    % dummy tag structure
  end
  fid = fopen(file, 'w');
  for name = fieldnames(snml)'
    if ismember(name{1}, {'units' 'tag'}), continue, end
    nl = snml.(name{1});
    nnls = length(nl);
    if ~isfield(snml.units, name{1})
      snml.units.(name{1})(nnls) = struct;
    end
    if ~isfield(snml.tag, name{1})
      snml.tag.(name{1})(nnls) = struct;
    end
    for inl = 1:nnls
      fprintf(fid, '&%s\n', name{1});
      vns0 = fieldnames(nl(inl));
      vns = vns0(~structfun(@isempty, nl(inl))); % skip empty fields
      nvns = length(vns);
      fvns = [' %-' num2str(max(cellfun(@length, vns))) 's = %s'];
      for nv = 1:nvns
        printvar(fid, fvns, vns{nv}, nl(inl).(vns{nv}), ...
                 snml.tag.(name{1})(inl), snml.units.(name{1})(inl), nv == nvns);
      end
      if nvns == 0
        fprintf(fid, '/\n');
      end
    end
  end
  fclose(fid);
end


function printvar (fid, fmt, name, value, tag, units, last)
  if last
    endfmt = '\n/\n';
  else
    endfmt = ',\n';
  end
  if isfield(units, name) && ~isempty(units.(name){1})
    oc = [tag.(name); num2cell(value); units.(name)];
    output = sprintf('%s %d %s,', oc{:});
  elseif iscell(value)
    if ismember(lower(value{1}), {'f' 't' 'false' 'true' '.false.' '.true.'})
      output = sprintf('%s,', value{:});
    else
      output = sprintf('''%s'',', value{:});
    end
  else
    output = sprintf('%d,', value);
  end
  fprintf(fid, [fmt endfmt], name, regexprep(output, ',$', ''));
end
