function hcb = colorbar(range, label, varargin)
%ODB.COLORBAR add colour bar to ODB contour plot
% H = ODB.COLORBAR(RANGE, LABEL, OPTIONS)
%   RANGE range for colour scale
%   LABEL label for colour bar
%   OPTIONS:
%     'fontsize', fs            font size for tick marks and label
%     'logfmt', fmt             format specification for logarithmic labels
%     'location', loc           location of colour bar within plot window
%     'position', [x0 y0 w h]   absolute position of colour bar
%
% See also COLORBAR, ODB.CON, NUM2STR
  ha = gca;
  pa = get(ha, 'Position');	% position of current axes
  opt.location = 'EastOutside';
  opt.fontsize = 12;
  opt.logfmt = '%0.2g';
  opt = oppla.pop({'fontsize' 'location' 'position' 'cbticks' 'cbwidth' 'logfmt'}, ...
                  {'log'}, opt, varargin{:});
  if ~isempty(regexp(opt.location, '[NnSs]o[ru]th', 'once'))
    bardir = 'X';	% cb orientation
    labfH = @xlabel;
    labarg = {};
    ipol = 1;		% index of offset in length direction
  else
    bardir = 'Y';
    labfH = @ylabel;
    labarg = {'VerticalAlignment' 'top'};
    ipol = 2;
  end
  ipow = 3 - ipol;	% index of offset in width direction
  ipl = ipol + 2;         % length index
  ipw = ipow + 2;         % width index
  if isfield(opt, 'position')
    hcb = colorbar('Position', opt.position);
  else
    hcb = colorbar(opt.location);	% plot colour bar
  end
  % ccb = get(hcb, 'child');        % this can be a vector
  % set (ccb(end), [bardir 'Data'], range);
  set (hcb, [bardir 'Lim'], range, 'FontSize', opt.fontsize);
  label = regexprep(label,  '\^([-0-9]+)', '\^{$1}');
  labfH(hcb, regexprep(label, '\\micro', '\\mu'), labarg{:}, ...
        'FontWeight', 'bold', ...
        'FontSize', opt.fontsize);
  if isfield(opt, 'cbticks')
    if isfield(opt, 'log')
      opt.cbticks = log10(opt.cbticks);
    end
    set (hcb, 'YTickMode', 'manual', 'YTick', opt.cbticks)
  end
  if isfield(opt, 'log')
    labels = str2double(get(hcb, [bardir 'TickLabel']));
    labels = num2str(10.^labels, opt.logfmt);
    set (hcb, 'YTickLabelMode', 'manual', 'YTickLabel', labels);
  end
  pc = get(hcb, 'Position');
  if isfield(opt, 'cbwidth')
    pc(ipow) = pc(ipow) + pc(ipw) - opt.cbwidth;
    pa(ipw) = pa(ipw) + pc(ipw) - 2*opt.cbwidth;
    pc(ipw) = opt.cbwidth;
  else
    wmin = 0.01;
    pc(ipol) = pc(ipol) + (pa(ipl)/2 + pa(ipol)) - (pc(ipl)/2 + pc(ipol));
    if (pc(ipow) < pa(ipow))
      pa(ipow) = pa(ipow) + pc(ipw);
      pa(ipw) = pa(ipw) - pc(ipw);
      pc(ipw) = pc(ipw)/2;
    else
      pa(ipw) = pc(ipow) - pa(ipow) - wmin;
    end
    if (pc(ipw) < wmin)
      if (pc(ipow) < pa(ipow))
        pc(ipow) = pc(ipow) - wmin - max(0, pc(ipw));
      end
      pc(ipw) = max(pc(ipw), wmin);
    end
  end
  set (hcb, 'Position', pc);
  set (ha, 'Position', max(pa, 0));
end
