function dbx = ext(db, varargin)
%ODB.EXT extract database with data from specified fields only
% DBX = ODB.EXT(DB, FN1, ...)
%   DB    OPPLA database
%   FN1   data fieldname in DB
%   DBX   database with only fields FN1, ...
%
% See also ODB.SUB
  if ischar(db)
    db = load(db);
  end
  irec = [];
  fns = varargin;
  dfns = setdiff(fieldnames(db), {'cruise' 'prf', 'rec'});
  if any(~ismember(fns, dfns))
    im = ~ismember(fns, dfns);
    error('OPPLA:ODB', ['ODB.EXT: fields ' fns{im} ' not in database.'])
  end
  nfs = length(fns);
  for nf=1:nfs
    irec = union(irec, db.(fns{nf}).rec);
  end
  [iprf, ~, dbx.rec.prf] = unique(db.rec.prf(irec));
  dbx.rec.depth = db.rec.depth(irec);
  dbx.prf = db.prf(iprf);
  [dbx.cruise, ~, crs] = unique(db.cruise([dbx.prf.crs]));
  crs = num2cell(crs);
  [dbx.prf.crs] = crs{:};
  for nf=1:nfs
    dbx.(fns{nf}).units = db.(fns{nf}).units;
    dbx.(fns{nf}).val = db.(fns{nf}).val;
    [~, dbx.(fns{nf}).rec] = ismember(db.(fns{nf}).rec, irec);
  end
end
