function [ups, dps] = fdp(data, field, varargin)
%ODB.FDP find duplicate profiles
% [UPS DPS] = ODB.FDP(DATA, FIELD, 'round', ND)
%   DATA  OPPLA database
%   FIELD field name in DATA
%   ND number of digits for option 'round'
%      with option 'round' lat and lon will be rounded to nd digits and
%      dates to whole days before trying to match profiles
%   UPS unique profiles (subset of profiles obtained with odb.prf)
%   DPS duplicate profile entries (identical dates and locations)
%       fields in DPS:
%       date, lat, lon: date and location
%       prf:            profile structure array for this date and location
%       crs:            cruise ids corresponding to prf
%
% See also ODB.FDR
  opt = oppla.pop({'round'}, {}, struct, varargin{:});
  prf = odb.prf(data, field);	% sort data into profiles
  ip = [prf.prf];
  if isfield(opt, 'round')
    fr = 10^opt.round;
    prfdat = round([data.prf(ip).date; ...
                    [data.prf(ip).lon].*fr; [data.prf(ip).lat].*fr]');
  else
    prfdat = [data.prf(ip).date; data.prf(ip).lon; data.prf(ip).lat]';
  end
  [~, iup] = unique(prfdat, 'rows');
  ups = prf(iup);			% subset of unique profiles
  imp = setdiff(1:length(prf), iup);	% indices of duplicate entries
  mps = unique(prfdat(imp,:), 'rows');
  nmp = size(mps, 1);
  dps = cell(1, nmp);
  for n=1:nmp
    dps{n} = prf(ismember(prfdat, mps(n,:), 'rows'));
  end
end
