function [ud, mulent] = fdr(file, field, varargin)
%ODB.FDR find duplicate record entries
% [UD, UC, ME] = ODB.FDR(FILE, FIELD)
%   FILE  OPPLA database or file name
%   FIELD field name in FILE
%   UD    unique records for FIELD
%   ME    structure array with multiple-entry info
%
% See also ODB.FDP
  opt = oppla.pop({}, {'display'}, [], varargin{:});
  if ischar(file)
    data = load(file);
  else
    data = file;
  end
  rec.prf = data.rec.prf(data.(field).rec);
  rec.depth = data.rec.depth(data.(field).rec);
  prf = data.prf(rec.prf);
  rd = [prf.date; prf.lon; prf.lat; rec.depth; data.(field).val]';
  [ud, id] = unique(rd, 'rows');
  nd = length(data.(field).val);
  if (nd == length(id))
    disp('No duplicates found')
  else
    im = setdiff(1:nd, id);       % indices of duplicate entries
    [md, ~, jd] = unique(rd(im,:), 'rows');
    nim = size(md, 1);
    mulent = repmat(struct('prf', 0, 'cruise', '', 'station', '', 'file', '', ...
                           'date', '', 'lon', 0, 'lat', 0, 'depth', 0, field, 0), ...
                    1, nim);
    for n=1:nim
      jm = find(jd == n);
      mulent(n).(field) = md(n,5);
      mulent(n).depth = md(n,4);
      mulent(n).date = datestr(md(n,1));
      mulent(n).lon = md(n,2);
      mulent(n).lat = md(n,3);
      mulent(n).cruise = data.cruise{[prf(im(jm)).crs]};
      mulent(n).station = data.station{[prf(im(jm)).stn]};
      mulent(n).file = data.file{[prf(im(jm)).file]};
      mulent(n).prf = rec.prf(im(jm));
      if isfield(opt, 'display')
        disp('Multiple entries: ')
        for k=1:length(jm)
          disp([num2str(rd(jm(k),1:4)) datestr(rd(jm(k),5)) ...
                data.cruise(rd(jm(k),1:3))])
        end
      end
    end
  end
end
