function gnc (db, ncfn, varargin)
%ODB.NC: read netcdf data into odb format
  if nargin > 2
    db = odb.ext(db, varargin{:});
  end
  %timfmt = 'yyyy-mm-ddTHH:MM:SSZ';
  %netcdf format following CF Metadata Conventions
  %mode = bitor(netcdf.getConstant('NC_SHARE'), ...
  %             netcdf.getConstant('NC_64BIT_OFFSET'));
  ncid = netcdf.create(ncfn, 'NC_SHARE'); % create file
  nc_global = netcdf.getConstant('NC_GLOBAL'); % write global attributes
  netcdf.putAtt(ncid, nc_global, 'Conventions', 'Unidata Observation Dataset v1.0');
  netcdf.putAtt(ncid, nc_global, 'cdm_datatype', 'StationCollectionOfProfiles');
  netcdf.putAtt(ncid, nc_global, 'uni_obs_style', 'consecutive');
  netcdf.putAtt(ncid, nc_global, 'observationDimension', 'record');
  netcdf.putAtt(ncid, nc_global, 'profileDimension', 'station');
  netcdf.putAtt(ncid, nc_global, 'parent_index_variable', 'station_index');
  netcdf.putAtt(ncid, nc_global, 'station_id', 'station_index');
  netcdf.putAtt(ncid, nc_global, 'profile_id', 'station_index');
  netcdf.putAtt(ncid, nc_global, 'latitude_coordinate', 'latitude');
  netcdf.putAtt(ncid, nc_global, 'longitude_coordinate', 'longitude');
  netcdf.putAtt(ncid, nc_global, 'zaxis_coordinate', 'depth');
  netcdf.putAtt(ncid, nc_global, 'time_coordinate', 'time');
  netcdf.putAtt(ncid, nc_global, 'geospatial_lat_max', max([db.prf.lat]));
  netcdf.putAtt(ncid, nc_global, 'geospatial_lat_min', min([db.prf.lat]));
  netcdf.putAtt(ncid, nc_global, 'geospatial_lon_max', max([db.prf.lon]));
  netcdf.putAtt(ncid, nc_global, 'geospatial_lon_min', min([db.prf.lon]));
  netcdf.putAtt(ncid, nc_global, 'time_coverage_start', min([db.prf.date]));
  netcdf.putAtt(ncid, nc_global, 'time_coverage_end', max([db.prf.date]));
  nps = length(db.prf);                   % No. of profiles/stations
  nobs = length(db.rec.prf);              % No. of observations
  [prf, irec] = sort(db.rec.prf);          % make station data contiguous
  crs = char(db.cruise([db.prf.crs]));
  len_crs = size(crs, 2);
  stn = char(db.station([db.prf.stn]));
  len_stn = size(stn, 2);
  %define dummy dimensions
  recdid = netcdf.defDim(ncid, 'record', netcdf.getConstant('NC_UNLIMITED'));
  prfdid = netcdf.defDim(ncid, 'station', nps);
  slcdid = netcdf.defDim(lcid, 'strlen_crs', len_crs);
  slsdid = netcdf.defDim(lcid, 'strlen_stn', len_stn);
  %timlid = netcdf.defDim(ncid, 'time_strlen', length(timfmt));
  lonid = netcdf.defVar(ncid, 'longitude', 'double', prfdid);
  netcdf.putAtt(ncid, lonid, 'long_name', 'station longitude');
  netcdf.putAtt(ncid, lonid, 'units', 'degrees_east');
  netcdf.putAtt(ncid, lonid, 'CoordinateAxisType', 'Lon');
  latid = netcdf.defVar(ncid, 'latitude', 'double', prfdid);
  netcdf.putAtt(ncid, latid, 'long_name', 'station latitude');
  netcdf.putAtt(ncid, latid, 'units', 'degrees_north');
  netcdf.putAtt(ncid, latid, 'CoordinateAxisType', 'Lat');
  timid = netcdf.defVar(ncid, 'time', 'double', prfdid);
  netcdf.putAtt(ncid, timid, 'long_name', 'time');
  netcdf.putAtt(ncid, timid, 'units', 'days since 0000-01-01T00:00:00Z');
  netcdf.putAtt(ncid, timid, 'CoordinateAxisType', 'Time');
  prfid = netcdf.defVar(ncid, 'station_index', 'int', recdid);
  netcdf.putAtt(ncid, prfid, 'long_name', 'index of parent station');
  depid = netcdf.defVar(ncid, 'depth', 'double', recdid);
  netcdf.putAtt(ncid, depid, 'long_name', 'depth below sea level');
  netcdf.putAtt(ncid, depid, 'units', 'm');
  netcdf.putAtt(ncid, depid, 'CoordinateAxisType', 'Height');
  netcdf.putAtt(ncid, depid, 'positive', 'down');

  crsid = netcdf.defVar(ncid, 'cruise', 'char', [prfdid slcdid]);
  netcdf.putAtt(ncid, crsid, 'long_name', 'cruise id')
  stnid = netcdf.defVar(ncid, 'station', 'char', [prfdid slsdid]);
  netcdf.putAtt(ncid, stnid, 'long_name', 'station id');

  % link stations to records via contiguous linked list
  fcid = netcdf.defVar(ncid, 'firstChild', 'int', prfdid);
  netcdf.putAtt(ncid, fcid, 'long_name', 'first record number in station');
  nocid = netcdf.defVar(ncid, 'numChildren', 'int', prfdid);
  netcdf.putAtt(ncid, nocid, 'long_name', 'number of records in station');

  % write (dummy) dimensions
  netcdf.endDef(ncid);
  netcdf.putVar(ncid, lonid, [db.prf.lon]);
  netcdf.putVar(ncid, latid, [db.prf.lat]);
  netcdf.putVar(ncid, timid, [db.prf.date]);
  netcdf.putVar(ncid, crsid, crs);
  netcdf.putVar(ncid, stnid, stn);
  netcdf.putVar(ncid, prfid, 0, nobs, prf);
  netcdf.putVar(ncid, depid, 0, nobs, db.rec.depth(irec));
  firstChild = zeros(1, nps);
  numChildren = zeros(1, nps);
  for np=1:nps
    inp = find(prf == np);
    firstChild(np) = inp(1) - 1;
    numChildren(np) = length(inp);
  end
  netcdf.putVar(ncid, fcid, firstChild);
  netcdf.putVar(ncid, nocid, numChildren);

  fns = setdiff(fieldnames(db), {'cruise' 'prf' 'rec'});
  missing = netcdf.getConstant('NC_FILL_DOUBLE');
  for fn=fns
    data = repmat(missing, 1, nobs);
    data(db.(fn{1}).rec) = db.(fn{1}).val;
    netcdf.reDef(ncid);
    datid = netcdf.defVar(ncid, fn{1}, 'double', recdid);
    netcdf.putAtt(ncid, datid, 'units', odb.ud(db.(fn{1}).units));
    netcdf.putAtt(ncid, datid, 'long_name', fn{1});
    netcdf.putAtt(ncid, datid, 'fill_value', missing);
    netcdf.putAtt(ncid, datid, 'missing_value', missing);
    netcdf.putAtt(ncid, datid, 'coordinates', 'time, longitude, latitude, depth');
    netcdf.endDef(ncid);
    netcdf.putVar(ncid, datid, 0, nobs, data(irec));
  end

  netcdf.close(ncid);
end
