function grd = grid(db, depth, time, varargin)
%ODB.GRID interpolate ODB data onto coarse rectangular grid
% GRD = ODB.GRID(DB, DEPTH, TIME, FIELDS, OPTIONS)
%   DB      odb data base
%   DEPTH   vector of mean layer depths
%   TIME    (regularly spaced) vector of Matlab date numbers
%   FIELDS  names of odb datasets
%   OPTIONS optional arguments:
%     'rundep', depth   extend depth boundaries by depth m for calculating
%                       running means
%     'runtim', days    use days as time window for running means
%                       default is (average) difference between times

  depbb = odb.depth(depth);
  opt.runtim = 0;
  opt.rundep = 0;
  [opt, fields] = oppla.pop({'rundep' 'runtim'}, {}, opt, varargin{:});
  dt = diff(time)./2;
  timbb = [time(1) - dt(1), time + [dt dt(end)]];
  grd.date = time;
  grd.depth = depth;
  for field=fields(:)'
    fn = field{1};
    dep = db.rec.depth(db.(fn).rec);
    tim = [db.prf(db.rec.prf(db.(fn).rec)).date];
    dat = db.(fn).val;
    for nx=1:length(time)
      for ny=1:length(depth)
        ival = (dep >= depbb(ny) - 0.5*opt.rundep) & (dep < depbb(ny+1) + 0.5*opt.rundep) ...
               & (tim >= timbb(nx) - 0.5*opt.runtim) & (tim < timbb(nx+1) + 0.5*opt.runtim);
        grd.(fn).mean(ny,nx) = mean(dat(ival), 'omitnan');
        grd.(fn).std(ny,nx) = std(dat(ival), 'omitnan');
      end
    end
    grd.units.(fn) = db.(fn).units;
  end
end
