function data = intp(db, depth, varargin)
%ODB.INTP interpolate profiles to common depth structure
% DATA = ODB.INTP(DB, DEPTH, FN1, FN2, ..., OPTIONS)
%  DB           OPPLA database
%  DEPTH        depth array
%  FN1, FN2, .. field names
%  DATA         structure with interpolated fields
%  OPTIONS      'timerange', 'station', 'location', 'latrange', 'lonrange': see odb.ipslab
%  This function works only on fields with 1D val field.
  [~, fnms] = oppla.pop({'location' 'station' 'timerange' 'latrange' 'lonrange'}, ...
                        {}, [], varargin{:});
  nfs = length(fnms);
  [prfs{1:nfs}] = odb.prf(db, varargin{:});
  ndep = length(depth);
  for np=1:nfs
    nps = length(prfs{np});
    data.(fnms{np}).val = zeros(ndep,nps);
    data.(fnms{np}).prf = zeros(1,nps);
    for nd=1:nps
      if length(prfs{np}(nd).depth) == 1
        data.(fnms{np}).val(:,nd) = NaN(ndep, 1);
      else
        [datdep, datval] = unidep(prfs{np}(nd).depth, prfs{np}(nd).(varargin{np}));
        data.(fnms{np}).val(:,nd) = interp1(datdep, datval, depth);
      end
      data.(fnms{np}).prf(nd) = prfs{np}(nd).prf;
    end
  end
end


function [udep, udat] = unidep (dep, dat)
% calculate unique profile by averaging values at the same depth
  [udep, id] = unique(dep);
  udat = dat(id);
  md = unique(dep(setdiff(1:length(dep), id)));
  if ~isempty(md)
    for n=1:length(md)
      udat(udep==md(n)) = mean(dat(dep == md(n)));
    end
  end
end
