function inv (db, file, ti)
%ODB.INV inventory
% ODB.INV(DB, FILE, TITLE)
% write inventory to tex file
  [fp, fn, ext] = fileparts(file);
  if ~strcmp(ext, '.tex')
    file = fullfile(fp, [fn '.tex']);
  end
  fns = setdiff(fieldnames(db), {'cruise' 'prf' 'rec'});
  fid = fopen(file, 'w+');
  fprintf(fid, ['\\documentclass[a4paper]{article}\n' ...
                '\\usepackage{nooffsets,units,dcolumn,amsmath}\n' ...
                '\\begin{document}\n']);
  if (nargin > 2)
    fprintf(fid, '\\section*{%s}\n', ti);
  end
  fprintf(fid, ['\\begin{tabular}{llrcD{-}{-}{11}}\nVariable & Units & ' ...
                '\\# of Profiles & Months & \\multicolumn{1}{c}{Dates} \\\\\n' ...
                ' \\hline\n']);
  for nf=1:length(fns)
    prf = odb.prf(db, fns{nf});
    np = length(prf);                     % number of profiles
    ip = [prf.prf];                       % profile indices
    date = [db.prf(ip).date];
    dv = datevec(date);
    months = unique(dv(:,2));             % month coverage
    months(isnan(months)) = [];
    mon = compact(months');
    units = strrep(db.(fns{nf}).units, '_', '\,');
    name = strrep(fns{nf}, '_', '\_');
    dates = datestr(date([1 end]), 'dd mmm yyyy');
    fprintf(fid, '%s & $\\unit{%s}$ & %0d & %s & \\text{%s}-\\text{%s} \\\\\n', ...
            name, units, np, mon, dates(1,:), dates(2,:));
  end
  fprintf(fid, '\\end{tabular}\n\\end{document}\n');
  fclose(fid);
end


function c = compact (l)                % compact month lists
  if length(l) <= 2
    c = num2str(l, '%0d,');
    c = c(1:end-1);
    return
  end
  dl = diff(l);
  i0 = find(dl > 1, 1, 'first');
  if isempty(i0)
    c = [num2str(l(1)) '--' num2str(l(end))];
  else
    c = [compact(l(1:i0)) ',' compact(l(i0+1:end))];
  end
end
