function iprf = ipslab(prf, varargin)
%ODB.IPSLAB get profile indices for specified timerange and location
% IPRF = ODB.IPSLAB(PRF, OPTIONS)
%   PRF       	OPPLA database prf field
%   OPTIONS:
%     'location', {[lon lat] rad}
%     'station', 'STN'
%     'timerange', [y0 m0 d1; y1 m1 d1] or [y0; y1]
%     'latrange', [l0 l1]       limit latitudes to l0 to l1
%     'lonrange', [l0 l1]       limit longitudes to l0 to l1
%   IPRF ...   profile indices
%
% See also ODB.GET, ODB.SUBSET

  opt = oppla.pop({'location' 'station' 'timerange' 'latrange' 'lonrange'}, {}, [], varargin{:});
  if isfield(opt, 'location')
    if iscell(opt.location)
      pos =  [opt.location{:}];
    else
      pos = odb.loc(opt.location);
    end
    iprf = find(sum([[prf.lon] - pos(1); [prf.lat] - pos(2)].^2, 1) ...
                <= pos(3)^2);
  elseif isfield(opt, 'station')
    iprf = find(strncmp({prf.station}, opt.station, length(opt.station)));
  else
    iprf = 1:length(prf);
  end
  if isfield(opt, 'timerange')
    sd = size(opt.timerange, 2);
    if (sd == 1)
      opt.timerange = [opt.timerange ones(length(opt.timerange), 2)];
    elseif (sd ~= 3) && (sd ~= 6)
      error ('ODB:ipslab: invalid date specification.')
    end
    opt.daterange = datenum(opt.timerange);
  end
  frngs = {'lat' 'lon' 'date'};
  for frng=frngs
    rngn = [frng{1} 'range'];
    if isfield(opt, rngn)
      iprf = iprf([prf(iprf).(frng{1})] >= opt.(rngn)(1) ...
                  & [prf(iprf).(frng{1})] < opt.(rngn)(2));
    end
  end
end
