function data = isct(db, varargin)
%ODB.ISCT retrieve intersection of profiles with complete records in all fields
% DATA = ODB.ISCT(DB, FN1, FN2, ..., OPTIONS)
%  DB           OPPLA database
%  FN1, FN2, .. field names
%  DATA         structure with all fields with all matching records
%  OPTIONS      'timerange', 'location', 'latrange', 'lonrange': see odb.ipslab
  [~, fnms, args] = oppla.pop({'location' 'station' 'timerange' 'latrange' 'lonrange'}, ...
                              {}, [], varargin{:});
  nfs = length(fnms);
  [prfs{1:nfs}] = odb.prf(db, fnms{:}, args{:});
  pfs = intersect([prfs{1}.prf], [prfs{2}.prf]);
  for n=3:nfs
    pfs = intersect(pfs, [prfs{n}.prf]);
  end
  nps = length(pfs);
  ip = zeros(1, nfs);
  for np=1:nps
    data(np).prf = pfs(np); %#ok
    ip(1) = find([prfs{1}.prf] == pfs(np));
    ip(2) = find([prfs{2}.prf] == pfs(np));
    datdep = intersect(prfs{1}(ip(1)).depth, prfs{2}(ip(2)).depth);
    data(np).depth = datdep; %#ok
    for n=3:nfs
      ip(n) = find([prfs{n}.prf] == pfs(np));
      datdep = intersect(datdep, prfs{n}(ip(n)).depth);
    end
    for n=1:nfs
      idat = ismember(prfs{n}(ip(n)).depth, datdep);
      fns = setdiff(fieldnames(prfs{n}(ip(n))), {'prf', 'depth'});
      for nf=1:length(fns)
        if isnumeric(prfs{n}(ip(n)).(fns{nf}))
          data(np).(fnms{n}).(fns{nf}) = prfs{n}(ip(n)).(fns{nf})(:,idat);
        else
          data(np).(fnms{n}).(fns{nf}) = prfs{n}(ip(n)).(fns{nf});
        end
      end
    end
  end
end
