function pos = loc (loc)
%ODB.LOC return position and radius of predefined regions for ODB
% POS = ODB.LOC(LOC)
%   LOC   predefined region ('BATS', 'LS', etc.) or coordinates ([lon lat])
%   POS   coordinates if LOC is a region name or vice versa
  poss = [-64.5   32.17   10                 % BATS
          -25      20      5                 % EUMELI
          -18.5    20.5    2                 % EU
          -21      18.5    2                 % ME
          -31      21      2                 % LI
          -52.5    57      3                 % CSS
          -63      44      3                 % LS
          -57.5    43.6    1                 % L
          -57.5    39      1                 % T1
          -54.5    36.8    1                 % T2
          -45.5    42.2    1                 % T3
          -45.5    46.5    1                 % T4
          -45.5    50.4    1                 % T5
          -45.5   54.7     1                 % T6
          -44.5   59.6        1.5               % T7
          -68.42  -50.67    3                 % KERFIX
          -20      47      2                 % NABE
          -15.5    29.17   2                 % ESTOC
          -26.21   25.1    1                 % ESTOC_LAN
          -19      59      2                 % OWSI
          -126     48.6     1                 % P2
          -126.67  48.65    1                 % P4
          -128.67  48.8     1                 % P8
          -130.67  49       1                 % P12
          -134.67  49       1                 % P16
          -138.67  49.57    1                 % P20
          -139.67  49.63    1                 % P21
          -145     50       1.5               % PAPA = P26
          -30      25      1                 % 2530
          -30      30      1                 % 3030
          -30      35      1                 % 3530
          -146.6    38      1                 % JKO (JAMSTEC)
          -144.9    33.84   1                 % NKO (JAMSTEC)
          -155      44      1                 % KNT (JAMSTEC)
          -144.46   32.32   1                 % KEO (JAMSTEC)
          -143.55   38.18   1                 % StA (JAMSTEC)
          -143.79   38.21   1                 % StB (JAMSTEC)
          -143.32   38.15   1                 % StC (JAMSTEC)
          -143.08   38.11   1                 % StD (JAMSTEC)
          -141.52   37.58   1                 % D01 (JAMSTEC)
          -141.47   37.33   1                 % D02 (JAMSTEC)
          -141.28   37      1                 % D03 (JAMSTEC)
          -141.15   36.69   1                 % D04 (JAMSTEC)
          -147.49   40.94   1                 % E01 (JAMSTEC)
          -147.16   41.10   1                 % E02 (JAMSTEC)
          -146.98   41.15   1                 % E03 (JAMSTEC)
          -146.55   41.24   1                 % E04 (JAMSTEC)
          -146.18   41.3    1                 % E05 (JAMSTEC)
          -141.5    36.48   1                 % F01 (JAMSTEC)
          -186.77   55.24   1                 % 001 (JAMSTEC)
          -144.77   31.2    1                 % 002 (JAMSTEC)
          -145      35      1                 % 004 (JAMSTEC)
          -149      40.25   1                 % 006 (JAMSTEC)
          -160      47      1                 % K2 (JAMSTEC)
          -160      47      1                 % K2 (JAMSTEC)
          -145      30      1                 % S1 (JAMSTEC)
          -145      30      1];               % S1 (JAMSTEC)
  locs = {'BATS' 'EUMELI' 'EU' 'ME' 'LI' 'LS' 'CSS' ...
          'L' 'T1' 'T2' 'T3' 'T4' 'T5' 'T6' 'T7' 'KERFIX' 'NABE' 'ESTOC' 'ESTOC_LAN' ...
          'OWSI' 'P2' 'P4' 'P8' 'P12' 'P16' 'P20' 'P21' 'PAPA' ...
          '2530' '3030' '3530' 'JKO' 'NKO' 'KNT' 'KEO' 'StA' 'StB' 'StC' 'StD' 'D01' ...
          'D02' 'D03' 'D04' 'E01' 'E02' 'E03' 'E04' 'E05' 'F01' '001' '002' '004' '006' 'K02' 'K2' 'S01' 'S1'};
  if ischar(loc)
    iloc = find(strcmp(loc, locs));
    if isempty(iloc)
      error('ODB:location', 'Unknown location %s.', loc);
    end
    pos = poss(iloc,:);
  else
    nps = size(loc, 1);                   % number of positions
    dpos = zeros(size(poss, 1), nps);
    r = 1;
    for np=1:nps
      if size(loc, 2) == 3
        r = loc(np, 3);
      end
      dpos(:,np) = sqrt((poss(:,1) - loc(np,1)).^2 + (poss(:,2) - loc(np,2)).^2)./r;
    end
    [mdp, iloc] = min(dpos, [], 1);
    pos = locs(iloc);
    if any(mdp' > poss(iloc,3))
      idiff = find(mdp' > poss(iloc,3));
      for n=1:length(idiff)
        id = idiff(n);
        disp(['odb.loc: Position difference ' num2str(id) ...
              ' (' num2str(mdp(id)) ') greater than specified radius for ' ...
              pos{id} ' (' num2str(poss(iloc(id),3)) ').'])
      end
    end
  end
end
