function db = rh5 (file)
%ODB.RH5 read OPPLA database from HDF5 file
% DB = ODB.RH5(FILE)
%  FILE     hdf5 file name
%  DB       OPPLA database structure
  cruise = h5read(file, '/cruise');
  nps = length(cruise);
  db.cruise = cell(nps, 1);
  for np=1:nps
    db.cruise{np} = cruise(np).Data;
  end
  hinfo = h5info(file);
  hgh = hinfo.GroupHierarchy;
  igprf = find(strcmp({hgh.Groups.Name}, '/prf'), 1);
  pfns = {hgh.Groups(igprf).Datasets.Name};
  for nf=2:length(pfns)
    prfdat = h5read(file, pfns{nf});
    ndat = length(prfdat);
    prfdat = num2cell(prfdat);
    db.prf(1:ndat).(strrep(pfns{nf}, '/prf/', '')) = prfdat{:};
  end
  db.rec.prf = h5read(file, '/rec/prf');
  db.rec.depth = h5read(file, '/rec/depth');
  dfns = setdiff({hgh.Groups.Name}, '/rec');
  for nf=1:length(dfns)
    ifn = strcmp(dfns{nf}, {hgh.Groups.Name});
    hfns = {hgh.Groups(ifn).Datasets.Name};
    fns = regexp(hfns, '[^/]+$', 'match');
    for n=1:length(fns)
      db.(dfns{nf}(2:end)).(fns{n}{1}) = h5read(file, hfns{n});
    end
    hatts = {hgh.Groups(ifn).Attributes.Name};
    atts = regexp(hatts, '[^/]+$', 'match');
    for na=1:length(atts)
      a = h5read(file, hatts{nf});
      db.(dfns{nf}(2:end)).(atts{nf}) = a.Data;
    end
  end
end
