function ris = ris(db, varargin)
%ODB.RIS return common record indices for several datasets
% RIS = ODB.RIS(DB, FN1, FN2, ..., OPTIONS)
%  DB           OPPLA database
%  FN1, FN2, .. field names
%  OPTIONS      'timerange', 'station', 'location', 'latrange', 'lonrange': see odb.ipslab
%  RIS          structure with fields:
%    rec        common records indices of all fields
%    FN1        indices in db.FN1.rec (and db.FN1.val) corresponding to RIS.rec
  [~, fnms, args] = oppla.pop({'location' 'station' 'timerange' 'latrange' 'lonrange'}, ...
                              {}, [], varargin{:});
  nfs = length(fnms);
  [prfs{1:nfs}] = odb.prf(db, fnms{:}, args{:});
  ris.rec = intersect([prfs{1}.prf], [prfs{2}.prf]);
  for n=3:nfs
    ris.rec = intersect(ris.rec, [prfs{n}.prf]);
  end
  for n=1:nfs
    ris.(fnms{n}) = find(ismember(db.(fnms{n}).rec, ris.rec));
  end
end
