function data = subset(db, varargin)
%ODB.SUBSET create a subset of db containing only profiles prf
% [DATA] = ODB.SUBSET(DB, PRF)
% [DATA] = ODB.SUBSET(DB, 'location', loc, 'timerange', [y0 m0 d0; y1 m1 d1])
%   DB    OPPLA database
%   PRF   vector of profile indices
%   DATA  DB subset
%
%   loc     location id or [lon lat rad], see odb.cnt and odb.loc
%   y, m, d year, month, day for timerange specification
%
% See also ODB.GET, ODB.PRF, ODB.CONTOUR, ODB.LOC
  if isempty(varargin)
    iprf = 1:length(db.prf);
  elseif ischar(varargin{1})
    prf = db.prf;
    [prf.station] = db.station{[prf.stn]};
    iprf = odb.ipslab(prf, varargin{:});
  else
    iprf = varargin{1};
  end
  [data.cruise, ~, crs] = unique(db.cruise([db.prf(iprf).crs]));
  [data.station, ~, stn] = unique(db.station([db.prf(iprf).stn]));
  [data.file, ~, fil] = unique(db.file([db.prf(iprf).file]));
  data.prf = db.prf(iprf);
  crs = num2cell(crs);
  stn = num2cell(stn);
  fil = num2cell(fil);
  [data.prf.crs] = crs{:};
  [data.prf.stn] = stn{:};
  [data.prf.file] = fil{:};
  [ir, jr] = ismember(db.rec.prf, iprf);
  rec = find(ir);
  data.rec.prf = jr(rec);
  data.rec.depth = db.rec.depth(rec);
  fns = setdiff(fieldnames(db), [fieldnames(data); 'file'; 'station']);
  for nf=1:length(fns)
    fn = fns{nf};
    [i1, j1] = ismember(db.(fn).rec, rec);
    irec = find(i1);
    if ~isempty(irec)
      data.(fn).rec = j1(j1~=0);
      dfns = setdiff(fieldnames(db.(fn)), 'rec');
      for n=1:length(dfns)
        if isnumeric(db.(fn).(dfns{n}))
          data.(fn).(dfns{n}) = db.(fn).(dfns{n})(:,irec);
        else
          data.(fn).(dfns{n}) = db.(fn).(dfns{n});
        end
      end
    end
  end
end
