function fs = sum (db, varargin)
%ODB.SUM add fields where all records are present
% FS = ODB.SUM(DB, 'F1', 'F2', ...)
%   DB          database in ODB format
%   F1, F2, ... names of fields to add   
%   FS          new database field with summed data (val subfields)
  nfs = length(varargin);
  if (nfs == 1)
    fs = db.(varargin{1});
  else
    fs = dbsum(db.(varargin{1}), db.(varargin{2}));
    for n=3:nfs
      fs = dbsum(fs, db.(varargin{n}));
    end
  end
end


function fs = dbsum (f1, f2)
  if ~strcmp(f1.units, f2.units)
    error('ODB:sum', 'All fields to be added must have the same units.')
  end
  [if1, rf2] = ismember(f1.rec, f2.rec);
  irf1 = find(if1);
  fs.rec = f1.rec(irf1);
  fs.val = f1.val(:,irf1) + f2.val(:,rf2(rf2~=0));
  fs.units = f1.units;
end
