function [data, rec, units, db] = var(db, varnam, varargin)
%ODB.VAR retrieve (an expression involving) a field of an odb database
% [DATA, REC, UNITS, APDSUB] = ODB.VAR(DB, EXPRESSION[, ...])
%   DB        odb database
%   EXPRESSION  field name in DB or an expression involving such field names
%   ...         arguments defining a subset of profiles, passed to ODB.PRF
%   DATA        content of field or result of expression
%   REC         vector of record indices for data in APDSUB
%   UNITS       units of field (empty for expressions)
%   APDSUB      subset of DB as defined by PRFARG
%
  fns = setdiff(fieldnames(db), {'cruise' 'station' 'file' 'prf' 'rec'});
  if ismember(varnam, fns)
    if ~isempty(varargin)
      prfdat = odb.prf(db, varnam, varargin{:});
      if isempty(prfdat)
        error('ODB:var', 'No data in specified time or region.')
      end
      db = odb.subset(db, [prfdat.prf]);
    end
    data = double(db.(varnam).val);
    rec = db.(varnam).rec;
    units = db.(varnam).units;
  else
    names = strcat(fns(1:end-1)', '|');
    names = strrep(['(' names{:} fns{end} ')'], '.', '\.');
    dfns = regexp(varnam, names, 'tokens');
    dfns = [dfns{:}];
    nds = length(dfns);
    if ~isempty(varargin)
      [prfdat{1:nds}] = odb.prf(db, dfns{:}, varargin{:});
      if any(cellfun(@isempty, prfdat))
        error('ODB:var', 'No data in specified time or region.')
      end
      prf = [prfdat{1}.prf];
      for n=2:nds
        prf = union(prf, [prfdat{n}.prf]);
      end
      db = odb.subset(db, prf);
    end
    rec = db.(dfns{1}).rec;
    for n=2:nds
      rec = intersect(rec, db.(dfns{n}).rec);
    end
    if isempty(rec)
      error('ODB:var', 'Incompatible datasets in expression for odb.var.')
    end
    for n=1:nds
      db.(dfns{n}).val = db.(dfns{n}).val(ismember(db.(dfns{n}).rec, rec));
    end
    data = double(eval(regexprep(varnam, names, 'db.$1.val')));
    units = regexprep(regexprep(varnam, '\.([*/^])', '$1'), names, 'units(''$1'')');
    u = regexp(units, 'units\(''([^'']+)''\)', 'tokens');
    for n=1:length(u)                   % try to get units for expression
      units = strrep(units, ['units(''' u{n}{1} ''')'], db.(u{n}{1}).units);
    end
    units = regexprep(units, '([*/](1[^.0-9eE]|1$)|(^1|[^.0-9])1\*)', '');
    units = regexprep(units, '(.+[^ ])( *[+-] *\1)+', '$1');
  end
end
