function wh5(file, db, varargin)
%ODB.WH5 write OPPLA database to HDF5 file
% ODB.WH5(FILE, DB, 'force')
%  FILE     hdf5 file name
%  DB       OPPLA database structure
%  'force'  optional flag to overwrite existing file
  opt = oppla.pop({}, {'force'}, [], varargin{:});
  if exist(file, 'file')
    if isfield(opt, 'force')
      delete(file)
    else
      error('ODB:exist', 'File %s exists, use option force to overwrite.', ...
            file)
    end
  end
  pfns = fieldnames(db.prf);
  h5write(file, '/cruise', db.cruise);
  for nf=1:length(pfns)                 % write profile fields
    h5write(file, ['/prf/' pfns{nf}], [db.prf.(pfns{nf})], 'WriteMode', 'append');
  end
  h5write(file, '/rec/prf', int32(db.rec.prf), 'WriteMode', 'append');
  h5write(file, '/rec/depth', db.rec.depth, 'WriteMode', 'append');
  dfns = setdiff(fieldnames(db), {'prf' 'cruise' 'rec'});
  attrib.AttachType = 'group';
  for nf=1:length(dfns)                   % write data fields
    h5write(file, ['/' dfns{nf} '/rec'], int32(db.(dfns{nf}).rec), ...
            'WriteMode', 'append');
    fns = setdiff(fieldnames(db.(dfns{nf})), 'rec');
    for nfd=1:length(fns)
      if isnumeric(db.(dfns{nf}).(fns{nfd}))
        h5write(file, ['/' dfns{nf} '/' fns{nfd}], db.(dfns{nf}).(fns{nfd}), ...
                'WriteMode', 'append');
      else
        attrib.AttachedTo = ['/' dfns{nf}];
        attrib.Name = fns{nfd};
        h5write(file, attrib, db.(dfns{nf}).(fns{nfd}), 'WriteMode', 'append');
      end
    end
  end
end
