function res = cat(varargin)
%OPPLA.CAT concatenate oppla (spinup) simulation results
% RES = OPPLA.CAT(R1, R2, ...)
%   R1, R2, ... oppla results structures as obtained with OPPLA.READ
%   RES         oppla results structure with all data in R1, ... concatenated;
%               if all R1, ... have the same dates, a dummy date vector is created
  dates = cellfun(@(x) x.date', varargin, 'UniformOutput', false);
  if isequal(dates{:})
    for n = 2:length(dates)
      dates{n} = dates{n} + (dates{n-1}(end) - dates{1}(1));
    end
  end
  res.date = [dates{:}];
  fns = fieldnames(varargin{1})';
  for fn = setdiff(fns, {'date' 'time' 'soma' 'flux'})
    if isequal(size(varargin{1}.(fn{1})), [length(varargin{1}.depth) length(varargin{1}.date)])
      x = cellfun(@(x) x.(fn{1}), varargin, 'UniformOutput', false);
      res.(fn{1}) = [x{:}];
    else
      res.(fn{1}) = varargin{1}.(fn{1});
    end
  end
  for fn = intersect(fns, {'soma', 'flux'})
    x = cellfun(@(x) permute(x.(fn{1}), [1 3 2]), varargin, 'UniformOutput', false);
    res.(fn{1}) = permute([x{:}], [1 3 2]);
  end
end
