function cmt = cmt(model, varargin)
%OPPLA.CMT monthly climatology of oppla model results
% CMT = OPPLA.CMT(MODEL[, VAR1, ...][, OPTIONS])
%   MODEL     is an OPPLA results structure
%   VAR1 ...  are the variable names
%   OPTIONS   'depthrange', [d0 d1], 'daterange', dr
%      dr can be a cell array of two date strings, e.g., {'1990-01-01', '2000-01-01'},
%      or a length-two vector of datetime objects
% See also DATETIME
  model = oppla.slab(model, varargin{:});
  fns = fieldnames(model);
  fns = fns(structfun(@(x) isequal(size(x), [length(model.depth) length(model.time)]), model))';
  [~, month] = datevec(model.date);
  [cmt.month, ~, im] = unique(month);
  for mon = cmt.month(:)'
    for fn = fns
      cmt.(fn{1}).all{mon} = model.(fn{1})(:, im == mon);
      cmt.(fn{1}).mean(:,mon) = mean(cmt.(fn{1}).all{mon}, 2);
      cmt.(fn{1}).var(:,mon) = var(cmt.(fn{1}).all{mon}, 0, 2);
    end
  end
  if ismember('depth', fieldnames(model))
    cmt.depth = model.depth;
    cmt.depth_edges = model.depth_edges;
    cmt.height = model.height;
  end
  cmt.longitude = model.longitude;
  cmt.latitude = model.latitude;
  cmt.units = model.units;
end
