function [hax, hcb] = contour(data, var, varargin)
%OPPLA.CONTOUR filled contour plot of oppla results
% [HAX HCB] = OPPLA.CONTOUR(DATA, VAR, OPTIONS)
%  DATA     structure obtained with OPPLA.READ
%  VAR      name of variable (field of DATA) to plot
%  OPTIONS  optional arguments:
%               'depthrange', depthrange
%               'daterange', daterange
%               'fontsize', fontsize
%               'range', range
%               'title', title
%               'log'
% Returns:
%   HAX 	axes handle
%   HCB 	colour bar handle
  datefield = cell2mat(intersect(fieldnames(data), {'date', 'month'}));
  opt.depthrange = [min(data.depth_edges(:)), max(data.depth_edges(:))];
  opt.daterange = [min(data.(datefield)(:)), max(data.(datefield)(:))];
  opt.fontsize = 18;
  vardat = data.(var);
  if isstruct(vardat)
    vardat = vardat.mean;
  end
  opt.range = [min(vardat(:)), max(vardat(:))];
  opt = oppla.pop({'daterange', 'depthrange', 'fontsize', 'range', 'title'}, ...
                  {'log'}, opt, varargin{:});
  idat = find((data.(datefield) >= opt.daterange(1)) & (data.(datefield) <= opt.daterange(2)));
  idep = find((data.depth >= opt.depthrange(1)) & (data.depth <= opt.depthrange(2)));
  if isfield(opt, 'log')
    id0 = vardat > 0;
    vardat(id0) = log10(vardat(id0));
    minval = min(vardat(id0(:))) - 1;
    if any(~id0(:))
      vardat(~id0) = minval;
    end
    r0 = opt.range(1) <= 0;
    if r0
      opt.range = [minval, log10(opt.range(2))];
    else
      opt.range = log10(opt.range);
    end
  end
  [~, h] = contourf(datenum(data.(datefield)(idat)), data.depth(idep), vardat(idep,idat));
  if strcmp(datefield, 'date')
    datetick
  end
  set(h, 'LineStyle', 'none')
  hax = gca;
  set(hax, 'YDir', 'reverse', 'FontSize', opt.fontsize)
  xlabel(datefield, 'FontSize', opt.fontsize)
  ylabel('depth / m', 'FontSize', opt.fontsize)
  hcb = colorbar;
  hcb.Label.String = [strrep(var, '_', '\_') ' / ' regexprep(data.units.(var), '([0-9-]+)', '^{$1}')];
  hcb.Label.FontSize = opt.fontsize;
  hcb.XLim = opt.range;
  if isfield(opt, 'log')
    ticklabs = 10.^hcb.Ticks;
    if any(~id0(:)) || r0
      ticklabs(1) = 0;
    end
    hcb.TickLabels = ticklabs;
  end
  if isfield(opt, 'title')
    title(opt.title, 'FontWeight', 'bold', 'FontSize', 1.2.*opt.fontsize);
  end
end
