function int = int(model, varargin)
%OPPLA.INT vertical integrals of oppla model results
% CMT = OPPLA.CMT(MODEL[, VAR1, ...][, OPTIONS])
%   MODEL     is an OPPLA results structure
%   VAR1 ...  are the variable names
%   OPTIONS   'depthrange', [d0 d1], 'daterange', dr
%      dr can be a cell array of two date strings, e.g., {'1990-01-01', '2000-01-01'},
%      or a length-two vector of datetime objects
% See also DATETIME
  model = oppla.slab(model, varargin{:});
  fns = fieldnames(model);
  fns = fns(structfun(@(x) isequal(size(x), [length(model.depth) length(model.time)]), model))';
  int.date = model.date;
  for fn = {'longitude', 'latitude'}
    int.(fn{1}) = model.(fn{1});
    int.units.(fn{1}) = model.units.(fn{1});
  end
  for fn = fns
    int.(fn{1}) = model.height*model.(fn{1});
    int.units.(fn{1}) = strrep(model.units.(fn{1}), 'm-3', 'm-2');
  end
end
