function [val, varargin, args] = pop(opts, flags, val, varargin)
%OPPLA.POP parse varargin for options with arguments and flags
% [VAL, VARARGIN, ARGS] = OPPLA.POP(OPTS, FLAGS, VAL, VARARGIN)
%   OPTS  cell array of names of options with arguments
%   FLAGS cell array of names of flags (options without arguments)
%   VAL   default settings for opts
%   ARGS  cell array of arguments removed from VARARGIN
%   if two or three outputs are requested, options found in OPTS and FLAGS
%   will be removed from VARARGIN
  args = {};
  if isempty(varargin)
    return
  end
  ias = find(cellfun(@ischar, varargin));
  rf = nargout > 1;
  ef = ~rf && isempty(strcmp('noerror', varargin(ias)));
  na = length(ias);
  n = 0;
  while (n < na)
    n = n + 1;
    ia = ias(n);
    switch lower(varargin{ia})
      case lower(opts)
        if length(varargin) == ia
          error('OPPLA:options', 'Option %s needs an argument.', varargin{ia})
        end
        val.(varargin{ia}) = varargin{ia+1};
        if (n < na)
          if (ia + 1) == ias(n+1)
            n = n + 1;
          end
        end
        if rf
          args(end+1:end+2) = varargin(ia:ia+1);
          varargin(ia:ia+1) = [];
          ias(n+1:end) = ias(n+1:end) - 2;
        end
      case lower(flags)
        val.(varargin{ia}) = 1;
        if rf
          args{end+1} = varargin{ia}; %#ok
          varargin(ia) = [];
          ias(n+1:end) = ias(n+1:end) - 1;
        end
      otherwise
        if ef
          error('OPPLA:options', 'Unknown option %s.', varargin{ia})
        end
    end
  end
end
