function data = read(file)
%OPPLA.READ read OPPLA netCDF output
% DATA = OPPLA.READ(FILE)
%   FILE   is the OPPLA netCDF model results file
%   DATA   is a structure with fields for all state variables, depth,
%          time, etc.
  info = ncinfo(file);
  ncid = netcdf.open(file);
  % state variables and dimensions
  for var=info.Variables
    name = var.Name;
    varid = netcdf.inqVarID(ncid, name);
    data.(name) = netcdf.getVar(ncid, varid);
    if ~isempty(var.Attributes) && ismember('units', {var.Attributes.Name})
      data.units.(name) = netcdf.getAtt(ncid, varid, 'units');
    end
  end
  netcdf.close(ncid)
  % convert model time into datetime
  dv = textscan(data.units.time, 'seconds since %d-%d-%d %d:%d:%d');
  data.date = datetime([dv{:}]) + seconds(data.time);
  data.height = diff(data.depth_edges);
  data.units.height = data.units.depth_edges;
  % add control_file etc. to the output
  atts = {'control_file' 'data_file' 'initial_conditions' 'parameter_file'};
  for natt = find(ismember({info.Attributes.Name}, atts))
    data.(info.Attributes(natt).Name) = info.Attributes(natt).Value;
  end
  for fn = intersect(fieldnames(data)', {'States' 'sms'})
    data.(fn{1}) = cellfun(@(x) strip(strrep(x, char(0), '')), ...
                           mat2cell(data.(fn{1})', ones(1, size(data.(fn{1}), 2)), size(data.(fn{1}), 1)), ...
                           'UniformOutput', false);
  end
  if isfield(data, 'soma')
    s = cellfun(@(x) squeeze(x), num2cell(data.soma, [2 3]), 'UniformOutput', false);
    data.soma = table(s{:}, 'VariableNames', data.sms);
  end
end
