function slab = slab(model, varargin)
%OPPLA.SLAB extract a time-depth slab from oppla results
% SLAB = OPPLA.SLAB(MODEL[, VAR1, ...][, OPTIONS])
%   MODEL     is an OPPLA results structure
%   VAR1 ...  are the variable names to extract
%   OPTIONS   'depthrange', [d0 d1], 'daterange', dr
%      dr can be a cell array of two date strings, e.g., {'1990-01-01', '2000-01-01'},
%      or a length-two vector of datetime objects
% See also DATETIME
  opt.depthrange = [model.depth_edges(1,1) model.depth_edges(2,end)];
  opt.daterange = [min(model.date) max(model.date)];
  fns = fieldnames(model);
  vars = fns(structfun(@(x) isequal(size(x), size(model.DIC)), model));
  [opt, varargin] = oppla.pop({'depthrange' 'daterange'}, vars, opt, varargin{:});
  if ~isempty(varargin)
    error('MODEL:cmt', 'No field %s in MODEL results structure.', varargin{1})
  end
  idep = model.depth_edges(2,:) >= opt.depthrange(1) & model.depth_edges(1,:) <= opt.depthrange(2);
  idat = model.date >= opt.daterange(1) & model.date <= opt.daterange(2);
  fns = setdiff(fieldnames(opt), {'depthrange' 'daterange'})';
  if isempty(fns)
    fns = vars(:)';
  end
  for fn=fns
    slab.(fn{1}) = model.(fn{1})(idep, idat);
    slab.units.(fn{1}) = model.units.(fn{1});
  end
  slab.date = model.date(idat);
  slab.time = model.time(idat);
  slab.depth = model.depth(idep);
  slab.depth_edges = max(min(model.depth_edges(:,idep), opt.depthrange(2)), opt.depthrange(1));
  slab.height = diff(slab.depth_edges);
  slab.longitude = model.longitude;
  slab.latitude = model.latitude;
  for fn={'longitude' 'latitude' 'time' 'depth' 'depth_edges' 'height'}
    slab.units.(fn{1}) = model.units.(fn{1});
  end
end
