read_bats <- function(bottle = "~/data/BATS/bottle/bats_bottle.txt",
                      pp = "~/data/BATS/bottle/bats_primary_production.txt",
                      pig = "~/data/BATS/bottle/bats_pigments.txt") {
  require(oppla)
  require(units)
  set_names_and_units <- function(file, data, ...) {
    data[data <= -9] <- NA # set missing values to NA
    nu <- strcapture(x = read.delim(file = file, header = FALSE, sep = "\n", ...)$V1,
                     pattern = "([^[:space:]]+)[[:space:]]+=[[:space:]]+([^\\(]+)(?:[[:space:]]+\\(([^\\)]+)\\))?",
                     proto = data.frame(name = character(), longname = character(), units = character()))
    nu$units[nu$units == "PSS-78"] <- "psu"
    nu$units[nu$units == "C"] <- "Celsius"
    nu$units <- sub(pattern = "Deg ", replacement = "degrees_", x = nu$units)
    iln <- grep(pattern = "[[:space:]]", x = nu$units)
    if (length(iln) > 0) {
      ## this is for bats_pigments, where the long names and units are given in parentheses
      nu$longname[iln] <- sub(pattern = "(.+) [^[:space:]]+", replacement = "\\1", x = nu$units[iln])
      nu$units[iln] <- sub(pattern = ".+ ([^[:space:]]+)", replacement = "\\1", x = nu$units[iln])
    }
    names(data)[match(nu$name, names(data))] <- nu$longname
    row.names(nu) <- nu$longname
    for (name in nu$longname[nchar(nu$units) > 0]) {
      tryCatch(expr = units(data[[name]]) <- nu[name, "units"],
               warning = function(w) {
                 data[name] <<- as.numeric(sub(pattern = ".+: numeric value ([^[:space:]]+) is ignored.*",
                                               replacement = "\\1", x = w)) * data[name]
               })
    }
    return(data)
  }
  ## read BATS bottle data
  bb <- set_names_and_units(file = bottle,
                            data = read.delim(file = bottle, skip = 59, check.names = FALSE, sep = ""),
                            skip = 25, nrows = 30)
  bb$date <- as.POSIXct(sprintf(fmt = "%s %04d", bb$yyyymmdd, bb$time), format = "%Y%m%d %H%M", tz = "Atlantic/Bermuda")
  ## read BATS primary production data
  bpp <- set_names_and_units(file = pp,
                             data = read.delim(file = pp, skip = 38, check.names = FALSE, sep = ""),
                             skip = 22, nrows = 13)
  inames <- pmatch(c("Latitude of water collection", "Longitude of water collection",
                     "Collection depth", "CTD temp", "salinity from goflo bottle or CTD"),
                   names(bpp))
  unames <- c(Latitude = "degrees_N", Longitude = "degrees_W", Depth = "m",
              "Temperature ITS-90" = "°C", Salinity = "psu")
  names(bpp)[inames] <- names(unames)
  for (name in names(unames)) units(bpp[[name]]) <- unames[[name]]
  bpp$date <- as.POSIXct(as.character(bpp$yymmdd_in), format = "%Y%m%d", tz = "Atlantic/Bermuda")
  iids <- match(bpp$Id, bb$Id, nomatch = 0)
  bpp[iids > 0, c("date", "Longitude", "Latitude")] <- bb[iids, c("date", "Longitude", "Latitude")]
  ## read BATS pigment data
  bpig <- set_names_and_units(file = pig,
                              data = read.delim(file = pig, skip = 51, check.names = FALSE, sep = ""),
                              skip = 23, nrows = 24)
  bpig$date <- as.POSIXct(sprintf(fmt = "%s %04d", bpig$yyyymmd, bpig$time), format = "%Y%m%d %H%M",
                          tz = "Atlantic/Bermuda")
  return(structure(Reduce(f = function(x, y) merge(x, y, all = TRUE),
                          x = list(bb[, -(2:4)], bpp[, -(2:3)], bpig[, -(2:4)])),
                   file = sub(pattern = "/[^/]+$", replacement = "", x = bottle)))
}
