## function to combine vertically-integrated zooplankton data from the WOD and from Head et al. (2003)
LSzoo <- function(file = "data/LSzoo.rds",
                  fileWOD = "data/LS_WOD_plankton.rds", fileHead03 = "data/LS_zoo_Head_2003.rds",
                  georange = list(lat = units::set_units(c(min = 40, max = 60), "degrees_N"),
                                  lon = units::set_units(c(min = -70, max = -50), "degrees_E"))) {
  suppressMessages(require(data.table))
  ## LS_WOD_plankton contains data from the WOD; all depth-integrated data are from 1965
  ## LS_zoo_Head_2003 was manually extracted from Table 4 of Head et al. (2003)
  wod <- data.table::as.data.table(readRDS(file = fileWOD))[
                       lat %between% georange$lat & lon %between% georange$lon &
                       measure_units_bio == "ml/m2", # extract vertical integrals to 100 m
                       j = .(lon, lat, date, lower_z_bio, upper_z_bio, measure_val_bio)][
                       j = depth := units::set_units(rowMeans(.SD), "m"), .SDcols = c("lower_z_bio", "upper_z_bio")][
                       ## convert: ml (*1000) -> mm3/m3 (/0.95, Sato et al. 2015) -> wet weight (*0.064) -> mg (/12) -> mmol
                       ## factor 0.064 = 0.4 * 0.16 (dry wt = 16% of wet wt, copepods are 84% water, Postel et al., 2000, p.91)
                       j = total := units::set_units(measure_val_bio * 1e3 / 0.95 * 0.064 / 12, "mmol m-2")]
  h03 <- data.table::as.data.table(readRDS(file = fileHead03))[zone %in% 2:4][ # exclude shallow coastal zones 1 & 5
                       j = total := units::set_units(total, "mmol m-2")]
  zoo <- rbind(as.data.frame(h03[j = .(date, total)]), as.data.frame(wod[j = .(date, total)]))
  saveRDS(zoo, file = file)
  return(zoo)
}
