plot_ls <- function(model, model_zoo, data, data_zoo, main = "") {
  op <- par(mfrow = c(2, 2), mar = c(1, 3.5, 3, 1), mgp = c(1.7, 0.7, 0))
  ## zooplankton plot
  units(data_zoo) <- units(model_zoo$zoo_C)
  plot(zoo_C + zoo_noSVM_C ~ I(mon + 1), data = model_zoo, type = "l",
       ylim = c(0, max(zoo_C + zoo_noSVM_C, data_zoo)),
       xlim = c(1, 12), xlab = "",
       ylab = units::make_unit_label("zooplankton", units(data_zoo)))
  lines(zoo_C ~ I(mon + 1), data = model_zoo, col = "blue")
  lines(zoo_noSVM_C ~ I(mon + 1), data = model_zoo, col = "green")
  points(5:7, data_zoo)
  legend("topright", legend = c("data", "all", "migrating", "non-migr."),
         pch = c(1, NA, NA, NA), lt = c(NA, 1, 1, 1), col = c("black", "black", "blue", "green"))
  md <- list(Chlorophyll = "phyt_Chl", Nitrate = "DIN", Phosphate = "DIP")
  n <- 0
  for (name in names(md)) {
    n <- n + 1
    par(mar = c(if (n > 1) 3 else 1, 3.5, if (n > 1) 1 else 3, 1))
    units(data[[name]]) <- units(model[[md[[name]]]])
    plot(data$mon + 1, data[[name]], ylim = c(0, max(c(data[[name]], model[[md[[name]]]]), na.rm = TRUE)),
         xlab = if (n > 1) "month" else "", xlim = c(1, 12),
         ylab = units::make_unit_label(name, units(data[[name]])))
    lines(model$mon + 1, model[[md[[name]]]])
    if (name == "Chlorophyll")
      legend("topright", legend = c("data", "model"), pch = c(1, NA), lt = c(NA, 1))
  }
  par(op)
  if (nzchar(main)) title(main = main, line = 2.5)
}

## plot vertical integrals for the upper 100 m
plot_ls_int <- function(model, data = readRDS("obs.rds"), main = "", ...) {
  cmt_model <- oppla::oppla_int(data = model, avc = "mon")
  max_depth <- attr(cmt_model, "depth")
  ht <- sort(unique(data$mean$height))
  bounds <- cumsum(ht)
  ib1 <- which.min(bounds < max_depth)
  dss <- subset(data$mean, subset = depth < bounds[ib1])
  dss$height[dss$depth == max(dss$depth)] <- max_depth - bounds[ib1 - 1]
  ds <- data.frame(mon = 0:11)
  for (column in c("Nitrate", "Phosphate", "Chlorophyll")) {
    name <- paste(column, "height", sep = " * ")
    ds[[column]] <- aggregate(as.formula(paste(name, "mon", sep = "~")), data = dss, FUN = sum,
                              na.action = na.pass, na.rm = TRUE)[[name]]
  }
  plot_ls(model = cmt_model, model_zoo = cmt_model, data = ds, data_zoo = data$zoo, main = main)
}

## plot zooplankton vertical integrals for 100 m and surface concentrations
plot_ls_cmt <- function(model, data = readRDS("obs.rds"), main = "", ...) {
  cmt_model <- subset(oppla::oppla_cmt(data = model, columns = c("phyt_Chl", "DIN", "DIP")),
                      subset = depth == min(depth))
  int_zoo <- oppla::oppla_int(data = model, columns = c("zoo_C", "zoo_noSVM_C"), avc = "mon")
  ds <- subset(data$mean, subset = depth == min(depth))
  plot_ls(model = cmt_model, model_zoo = int_zoo, data = ds, data_zoo = data$zoo, main = main)
}
