#' @import units
#' @import ggplot2
#' @import data.table
NULL

## define oppla-specific units gChl, molC, molN, molP, psu and set the units
## options negative_power = TRUE and set_units_mode = "standard"
.onLoad <- function(libname, pkgname) {
  units::units_options(negative_power = TRUE, set_units_mode = "standard")
  tryCatch(units::make_units(molC), error = function(x) {
    units::install_unit(symbol = c("g", "gChl"), def = "g")
    units::install_unit(symbol = c("mol", "molC", "molN", "molP", "molFe", "molO2"), def = "mol",
                        name = paste("moles", c("carbon", "nitrogen", "phosphorus", "iron", "oxygen"), sep = "_"))
    units::install_unit(symbol = "gC", def = "molC/12.011")  # 12.011 g/mol
    units::install_unit(symbol = "gN", def = "molN/14.007")  # 14.007 g/mol
    units::install_unit(symbol = "gP", def = "molP/30.97376")  # 30.97376 g/mol
    units::install_unit(symbol = "gFe", def = "molFe/55.845")  # 55.845 g/mol
    units::install_unit(symbol = "gO2", def = "moles_oxygen/31.998") # 31.998 g/mol
    units::install_unit(symbol = c("psu", "permil"), def = "1000 ppm")
    units::install_unit(symbol = "equiv", def = "1 mol/kg")
    units::install_unit(symbol = "cell", name = "cells")
  })
  data.table::setDTthreads(threads = 1)
}
