% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/oppla_data.R
\name{op_aggregate}
\alias{op_aggregate}
\title{Aggregate data onto a regular time-depth grid.}
\usage{
op_aggregate(
  data,
  edges = layers,
  datecols = c("year", "month"),
  layers = 20,
  drop_na = TRUE,
  columns = names(data)[sapply(X = data, FUN = is.numeric)],
  fun = mean,
  ...
)
}
\arguments{
\item{data}{bottle data from \code{read_ls} or \code{read_bats} or one of the .rds files}

\item{edges}{number of layers or vector or matrix of edges}

\item{datecols}{date columns (subset of names of the single-argument functions (year, month, etc.)
listed under \code{\link[data.table:IDateTime]{IDateTime}}) or \code{"date"}}

\item{layers}{number of layers or vector or matrix of edges}

\item{drop_na}{whether to drop empty rows}

\item{columns}{names of columns to include}

\item{fun}{function to apply to subsets}

\item{...}{optional arguments to \code{fun}}
}
\value{
\code{\link[data.table:data.table]{Data table}} of spatially and temporally averaged observations.
}
\description{
Spatial and/or temporal averages of \code{oppla} results.
}
\details{
In order to obtain layers matching oppla model output, use

\if{html}{\out{<div class="sourceCode">}}\preformatted{oa <- op_aggregate(data, edges = attr(model, "depth_edges"), ...)
}\if{html}{\out{</div>}}

If \code{datecols} does not contain "year", data are first averaged within years and then
\code{fun} is applied across years, in order to obtain better climatological values.
If \code{datecols} is \code{"date"}, aggregate only by depth level
}
