% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/oppla_forcing.R
\name{oppla_forcing_foci}
\alias{oppla_forcing_foci}
\title{Create oppla forcing file from FOCI output.}
\usage{
oppla_forcing_foci(
  foci_file,
  ilon = 1:3,
  ilat = 1:3,
  filename,
  vdc_cap = Inf,
  surface = list(),
  max_depth
)
}
\arguments{
\item{foci_file}{FOCI output file (NetCDF) with datasets for vertical eddy diffusivity,
temperature, salinity, surface wind speed, etc. (see Details).
Each dataset is expected to contain 9 vertical columns corresponding to a \eqn{3 \times 3}
subset of the horizontal FOCI grid.}

\item{ilon, ilat}{longitude and latitude indices to include in the horizontal averages}

\item{filename}{name of the oppla forcing file to be created}

\item{vdc_cap}{upper limit of vertical diffusivity (\eqn{\mathrm{m^2 s^{-1}}})}

\item{surface}{named list of paths to NCEP dataset collections;
The names are passed as \code{varid}s to \code{\link{oppla_read_ncep}}}

\item{max_depth}{if provided, exclude only layers below this depth (m), otherwise include only
layers above the sea floor at all positions in \code{foci_file}}
}
\description{
Detect forcing data for \code{oppla} in a FOCI output file and create an \code{oppla} forcing file.
}
\details{
\code{oppla_forcing_foci} detects forcing data according to this scheme:
\tabular{ll}{
\strong{FOCI} \tab \strong{oppla} \cr
votkeavt \tab D (vertical eddy diffusivity) \cr
votemper \tab Temperature  \cr
vosaline \tab Salinity     \cr
sowindsp \tab wind         \cr
ileadfra \tab ice_fraction
}
Additional time-series (1D) datasets can be added with \code{\link{oppla_forcing_add_ts}}.  Note that the
first level of vertical diffusivities is for the sea surface in FOCI, whereas OPPLA requires them
at the bottom of each layer.  Thus, \code{oppla_forcing_foci} omits the surface diffusivities.
}
