! compile with (see Makevars):
! $FC $(R CMD config FCFLAGS) $(R CMD config FPICFLAGS) -c rkde.f90
! R CMD SHLIB rkde.f90
SUBROUTINE oppla_cdd (nx, nrun, x, run, R, sigma, cdd)
  ! from Markus Schartau, translated to Fortran and also to return cumulative density
  ! this subroutine does not return the kde for speed
  ! input
  !   nx, nrun: lengths of x, run
  !   x:        input data
  !   run:      vector of points for which densities are estimated
  !   R:        inter-quartile range
  !   sigma:    standard deviation of x
  ! output
  !   cdd:      cumulative density distribution
  USE et
  IMPLICIT NONE
  INTEGER, INTENT(IN) :: nx, nrun
  REAL(dp), INTENT(IN) :: x(nx), run(nrun), R, sigma
  REAL(dp), INTENT(OUT) :: cdd(nrun)
  REAL(dp) :: pdd(nrun), kde(nx,nrun)
  CALL oppla_kde (nx, nrun, x, run, R, sigma, kde, pdd, cdd)
END SUBROUTINE oppla_cdd

SUBROUTINE oppla_kde (nx, nrun, x, run, R, sigma, kde, pdd, cdd)
  ! from Markus Schartau, translated to Fortran
  ! input
  !   nx, nrun: lengths of x, run
  !   x:        input data
  !   run:      vector of points for which densities are estimated
  !   R:        inter-quartile range
  !   sigma:    standard deviation of x
  ! output
  !   kde:      kernel density estimates
  !   pdd:      probability density distribution
  !   cdd:      cumulative density distribution
  USE et
  IMPLICIT NONE
  INTEGER, INTENT(IN) :: nx, nrun
  REAL(dp), INTENT(IN) :: x(nx), run(nrun), R, sigma
  REAL(dp), INTENT(OUT) :: kde(nx,nrun), pdd(nrun), cdd(nrun)
  REAL(dp) :: min_ref, h, hh(nx), fhh(nx)
  INTEGER :: n
  min_ref = MIN(sigma, R/1.34_dp)
  h = 1.06_dp*min_ref*nx**(-0.2_dp) ! plug-in formula
  hh = MIN(h, x/3._dp)              ! band width
  fhh = SQRT(2._dp*pi)*hh
  DO n=1,nx                     ! individual kernel densities
     kde(n,:) = EXP(-0.5_dp*((run - x(n))/hh(n))**2)/fhh(n)
  END DO
  pdd = SUM(kde, DIM=1)/nx
  cdd(1) = 0._dp
  DO n=2,nrun                   ! trapezoidal rule
     cdd(n) = cdd(n-1) + (pdd(n-1) + pdd(n))/2._dp * (run(n) - run(n-1))
  END DO
END SUBROUTINE oppla_kde
