PROGRAM oppla
#ifdef IFORT
  USE IFPORT
#endif
  USE clops
  USE plankton
  USE dvode
  IMPLICIT NONE
  TYPE(VODE_OPTS) :: options
  CHARACTER(LEN=*), PARAMETER :: opts='diop:crfmv',&
       usage='oppla [-d data] [-i init] [-o outfile | -c | -r] [-p param] [-m] [-f] [-v] control_file',&
       help='(A/&
       &"-p param       (pfn) file with parameter namelists  (default=control_file)"/&
       &"-d data        (dfn) file with physical data (netcdf)"/&
       &"-i init        (ifn) file with initial conditions (netcdf)"/&
       &"-o outfile     (ofn) output file (netcdf)"/&
       &"-c or -r             resume interrupted simulation"/&
       &"-f                   overwrite output file if it exists"/&
       &"-m            (soma) write source and flux matrices to output file"/&
       &"-v      (.NOT.quiet) show DVODE error messages"/&
       &"Names in parentheses correspond to namelist \"files\" in the input file,"/&
       &"quiet is in namelist vode."/"Pressing CTRL-C stops integration.")'
  CHARACTER(LEN=NF90_MAX_NAME), TARGET :: fnms(5)=''
  CHARACTER(LEN=NF90_MAX_NAME), POINTER :: dfn=>fnms(1), ifn=>fnms(2),&
       ofn=>fnms(3), pfn=>fnms(4), control=>fnms(5)
  INTEGER :: istate, ndil=1, nst=0, nts0=0, nts=0, nfe=0, exd, exh, exm,&
       exc0, exc1, excs, exct, ncps, istats(31)
  REAL(dp) :: exs, tout, tout_sun, tcrit, rstats(22)
  LOGICAL, TARGET :: flags(5)=.FALSE.
  LOGICAL :: keep_going=.TRUE., keep_going_main=.TRUE.
  LOGICAL, POINTER :: resume=>flags(1), force=>flags(3), soma=>flags(4), verb=>flags(5)
  CALL SYSTEM_CLOCK (COUNT=exc0, COUNT_RATE=ncps)
  excs = exc0
#ifdef IFORT
  istate = SIGNAL(2, catch_signal_2, -1)
#else
  istate = SIGNAL(2, catch_signal_2)
#endif
  control = 'oppla_control.nml'
  CALL getopt (opts, fnms, flags, usage, help)
  parode%quiet = .NOT.verb
  resume = resume.OR.flags(2)
  CALL plankton_init (control=control, dfn0=dfn, ifn0=ifn, ofn0=ofn, pfn0=pfn, sms0=soma, force=force, resume=resume)
  times%timeout = times%timeout*ncps
  IF (parode%quiet) CALL XSETF (0)
  times%previous = times%now
  main: DO WHILE ((times%now.LT.times%end).AND.keep_going_main)
     ! integration should stop at sunrise, noon, and sunset, without creating
     ! excessive numbers of extra time steps
     ! first, check whether it is after sunset; if so, go to the next day
     IF ((times%now.GE.times%sun(4)).OR.(times%now.LT.(times%sun(4) - 86.4e3_dp))) &
          CALL times%sunday (env=envir)
     ! tout sun is the next sunrise, noon, or sunset after times%now
     tout_sun = MINVAL(times%sun, MASK=times%sun.GT.times%now)
     ! tout is the end of the next full time step or tout_sun
     tout = MIN(times%start + (nts + 1)*times%dto, tout_sun)
     ! if the next sunrise, noon, or sunset is less than times%dto after tout,
     ! extend tout until then
     IF ((tout_sun - tout).LT.times%dto) tout = tout_sun
     IF (times%dilute) tout = MIN(tout, times%dil_time(ndil))
     tcrit = tout
     options = SET_OPTS(TCRIT=tcrit, RELERR_VECTOR=parode%rtol, ABSERR_VECTOR=parode%atol,&
          METHOD_FLAG=parode%mf, H0=parode%h0, HMAX=parode%hmax, HMIN=parode%hmin,&
          MAXORD=parode%maxord, MXSTEP=parode%mxstep, MXHNIL=parode%mxhnil,&
          CONSTRAINED=parode%constrained, CLOWER=parode%clower,&
          CUPPER=parode%cupper, SPARSE_J=parode%sparse_jacobian)
     DO WHILE ((times%now.LT.tout).AND.keep_going)
        istate = 1
        CALL VODE_F90 (plankton_ode, parode%neq, states%all_states, times%now, tout, parode%itask, istate, options)
        SELECT CASE (istate)
        CASE (2)
           IF (options%mf.NE.parode%mf) &
                options = SET_OPTS(TCRIT=tcrit, RELERR_VECTOR=parode%rtol, ABSERR_VECTOR=parode%atol,&
                METHOD_FLAG=parode%mf, H0=parode%h0, HMAX=parode%hmax, HMIN=parode%hmin,&
                MAXORD=parode%maxord, MXSTEP=parode%mxstep, MXHNIL=parode%mxhnil,&
                SPARSE_J=parode%sparse_jacobian, CONSTRAINED=parode%constrained,&
                CLOWER=parode%clower, CUPPER=parode%cupper)
           CALL SYSTEM_CLOCK (COUNT=excs)
        CASE (-1)               ! excessive work: continue with diagonal Jacobian
           options = SET_OPTS(TCRIT=tcrit, RELERR_VECTOR=parode%rtol, ABSERR_VECTOR=parode%atol,&
                METHOD_FLAG=parode%jsv*(10*parode%meth + 3), H0=parode%h0, HMAX=parode%hmax, HMIN=parode%hmin,&
                MAXORD=parode%maxord, MXSTEP=parode%mxstep, MXHNIL=parode%mxhnil, SPARSE_J=parode%sparse_jacobian,&
                CONSTRAINED=parode%constrained, CLOWER=parode%clower, CUPPER=parode%cupper)
        CASE (-5)               ! convergence test failures
           ! temporarily switch to full Jacobian and lower accuracy
           options = SET_OPTS(TCRIT=tcrit, RELERR_VECTOR=parode%mxrtol, ABSERR_VECTOR=parode%mxatol,&
                METHOD_FLAG=parode%jsv*(10*parode%meth + 2), H0=parode%h0, HMAX=parode%hmax, HMIN=parode%hmin,&
                MAXORD=parode%maxord, MXSTEP=parode%mxstep, MXHNIL=parode%mxhnil, SPARSE_J=parode%sparse_jacobian,&
                CONSTRAINED=parode%constrained, CLOWER=parode%clower, CUPPER=parode%cupper)
           CALL SYSTEM_CLOCK (COUNT=exct)
           IF ((times%timeout.GT.0).AND.((exct - excs).GT.times%timeout)) THEN
              WRITE (stdout,'(/"timeout reached")')
              EXIT main
           END IF
        CASE DEFAULT
           EXIT
        END SELECT
        IF (.NOT.parode%quiet) THEN
           CALL GET_STATS (rstats, istats)
           nst = nst + istats(11)
           nfe = nfe + istats(12)
        END IF
     END DO
     nts = FLOOR((times%now + 1.e-3_dp - times%start)/times%dto)
     IF (nts.NE.nts0) THEN
        CALL states%write (times=times, env=envir) ! outsv in onf.f90
        times%previous = times%now
     END IF
     IF ((istate.NE.2).AND.(istate.NE.-1).AND.(istate.NE.-5)) THEN
        WRITE (*,'(/"istate = ",I2," at time ",ES15.6)') istate, tout
        EXIT
     END IF
     IF (times%dilute) THEN
        IF (times%now.GE.times%dil_time(ndil)) THEN
           states%data = states%data*times%dil_fact(ndil)
           states%data(envir%idin,:) = states%data(envir%idin,:) + (1D0 - times%dil_fact(ndil))*times%dil_DIN(ndil)
           states%data(envir%idip,:) = states%data(envir%idip,:) + (1D0 - times%dil_fact(ndil))*times%dil_DIP(ndil)
           times%dilute = ndil.LT.times%ndil
           ndil = ndil + 1
        END IF
     END IF
     nts0 = nts
  END DO main
  CALL states%close             ! exof in onf.f90
  IF (.NOT.parode%quiet) &
       WRITE (stdout,FMT='(/"No. of steps: ",I0,".  No. of function calls: ",I0,".")') nst, nfe
  CALL SYSTEM_CLOCK (COUNT=exc1)
  CALL Jul_DHMSofSec ((exc1 - exc0)/ncps, exd, exh, exm, excs)
  WRITE (stdout,'(/"Integration took ",I0,":",I2.2,":",I2.2,".",I3.3)') exd*24 + exh, exm, excs, &
       INT(MOD(exs, 1._dp)*1.E3_dp)
  IF (istate.EQ.2) WRITE (stdout,FMT='(/"Oppla finished normally.")')
CONTAINS
  FUNCTION catch_signal_2 (signal) RESULT (n)
    IMPLICIT NONE
    INTEGER :: signal, n
    keep_going = keep_going_main
    keep_going_main = .FALSE.
    CALL XSETF (1)
    n = 0
  END FUNCTION catch_signal_2
END PROGRAM oppla
